import { useEffect } from 'react';
import { useTradeStore } from '../store';
import { useShallow } from 'zustand/react/shallow';
import { Modal, Space } from 'antd';
import dayjs from 'dayjs';
import { Table, Button, Select, DatePicker, Input, Form } from 'antd';
import { ColumnType } from 'antd/es/table/interface';

const defaultValues = {
  title: '',
  userId: '',
  level: 'free',
  category: 'center',
  startDate: dayjs(),
  endDate: dayjs().add(1, 'month'),
};
export const EditDialog = () => {
  const [form] = Form.useForm();
  const store = useTradeStore(
    useShallow((state) => ({
      formData: state.formData,
      setFormData: state.setFormData,
      showEdit: state.showEdit,
      setShowEdit: state.setShowEdit,
      updateData: state.updateData,
    })),
  );
  useEffect(() => {
    if (store.showEdit) {
      if (store.formData) {
        form.setFieldsValue({
          ...store.formData,
          startDate: dayjs(store.formData.startDate),
          endDate: dayjs(store.formData.endDate),
        });
      } else {
        form.setFieldsValue(defaultValues);
      }
    }
    return () => {
      form.setFieldsValue(defaultValues);
    };
  }, [store.formData, store.showEdit]);
  const onSubmit = async (data: any) => {
    // 将dayjs对象转换为时间字符串
    const formattedData = {
      ...data,
      id: store.formData?.id,
      startDate: data.startDate ? data.startDate.format('YYYY-MM-DD') : undefined,
      endDate: data.endDate ? data.endDate.format('YYYY-MM-DD') : undefined,
    };
    const res = await store.updateData(formattedData, { refresh: true });
    if (res.code === 200) {
      store.setShowEdit(false);
      store.setFormData(undefined);
    }
  };
  const onCancel = () => {
    store.setShowEdit(false);
    store.setFormData(undefined);
  };
  const hasId = !!store.formData?.id;
  return (
    <Modal
      title={hasId ? '编辑' : '添加'}
      footer={null}
      open={store.showEdit}
      onCancel={onCancel}
      style={{
        top: 40,
      }}>
      <Form
        form={form}
        labelCol={{
          span: 6,
        }}
        wrapperCol={{
          span: 18,
        }}
        className='flex flex-col gap-4 pt-4 min-w-[400px]'
        onFinish={onSubmit}>
        <Form.Item name='id' hidden>
          <Input />
        </Form.Item>
        <Form.Item name='title' label='标题' rules={[{ required: true, message: '请输入标题' }]}>
          <Input placeholder='请输入标题' />
        </Form.Item>
        <Form.Item name='userId' label='用户ID' rules={[{ required: true, message: '请输入用户ID' }]}>
          <Input placeholder='请输入用户ID' />
        </Form.Item>
        <Form.Item label=' ' colon={false}>
          <Button htmlType='submit'>提交</Button>
        </Form.Item>
      </Form>
    </Modal>
  );
};

export const List = () => {
  const store = useTradeStore(
    useShallow((state) => ({
      list: state.list,
      pagination: state.pagination,
      init: state.init,
      setShowEdit: state.setShowEdit,
      deleteData: state.deleteData,
      setFormData: state.setFormData,
      userList: state.userList,
      getList: state.getList,
    })),
  );
  useEffect(() => {
    store.init();
  }, []);
  const columns: ColumnType<any>[] = [
    {
      title: 'ID',
      dataIndex: 'id',
      align: 'center',
    },
    {
      title: 'out_trade_no',
      dataIndex: 'out_trade_no',
      align: 'center',
    },
    {
      title: 'Subject',
      dataIndex: 'subject',
      align: 'center',
    },
    {
      title: '状态',
      dataIndex: 'status',
      align: 'center',
    },
    {
      title: '金额',
      dataIndex: 'money',
      align: 'center',
      render: (_, record) => {
        try {
          return (record.money / 100).toFixed(2);
        } catch (error) {
          return record.money;
        }
      },
    },
    {
      title: '支付方式',
      dataIndex: 'type',
      align: 'center',
    },
    {
      title: 'uid',
      dataIndex: 'uid',
      align: 'center',
      render: (_, record) => {
        const user = store.userList?.find?.((item) => item.id === record.uid);
        return user?.username || record.uid;
      },
    },
    {
      title: '数据',
      dataIndex: 'data',
      align: 'center',
      render: (_, record) => {
        const target = record.data?.target;
        return JSON.stringify(target);
      },
    },
    {
      title: '创建时间',
      dataIndex: 'createdAt',
      align: 'center',
      render: (_, record) => {
        return record.createdAt ? dayjs(record.createdAt).format('YYYY-MM-DD HH:mm:ss') : '';
      },
    },
    {
      title: '操作',
      dataIndex: 'action',
      align: 'center',
      fixed: 'right',
      render: (_, record) => (
        <Space>
          <Button
            type='link'
            onClick={() => {
              store.setShowEdit(true);
              store.setFormData(record);
            }}>
            编辑
          </Button>
          <Button type='link' onClick={() => store.deleteData(record.id)}>
            删除
          </Button>
        </Space>
      ),
    },
  ];
  const [formSearch] = Form.useForm();
  const onSearch = (data: any) => {
    console.log('onSearch', data);
    store.getList(data);
  };
  return (
    <div className='w-full h-full flex flex-col gap-2 bg-gray-100 p-4'>
      <div
        className='overflow-auto scrollbar relative'
        style={{
          height: 'calc(100% - 50px)',
          overflow: 'auto',
        }}>
        <Form form={formSearch} onFinish={onSearch} layout='inline' className='sticky top-0 left-0 z-10 flex gap-2 flex-wrap'>
          {/* <Button type='primary' onClick={() => store.setShowEdit(true)}>
            添加
          </Button> */}
          <Form.Item className='w-[200px]' name='search' label='标题'>
            <Input />
          </Form.Item>
          <Form.Item>
            <Button type='primary' htmlType='submit'>
              搜索
            </Button>
          </Form.Item>
        </Form>
        <Table
          className='mt-2'
          columns={columns}
          rowKey={(record) => record.id}
          dataSource={store.list}
          pagination={{
            pageSize: store.pagination.pageSize,
            total: store.pagination.total,
            current: store.pagination.page,
            onChange: (page, pageSize) => {
              store.getList({ page, pageSize });
              console.log('onChange', page, pageSize);
            },
          }}
        />
      </div>
      <EditDialog />
    </div>
  );
};
