import { useEffect } from 'react';
import { useDemoStore } from '../store';
import { useShallow } from 'zustand/react/shallow';
import { Modal, Space } from 'antd';
import { vipLevel, VipCategory } from '../query.ts';
import dayjs from 'dayjs';
import { Table, Button, Select, DatePicker, Input, Form } from 'antd';
import { ColumnType } from 'antd/es/table/interface';

const defaultValues = {
  title: '',
  userId: '',
  level: 'free',
  category: 'center',
  startDate: dayjs(),
  endDate: dayjs().add(1, 'month'),
};
export const EditDialog = () => {
  const [form] = Form.useForm();
  const store = useDemoStore(
    useShallow((state) => ({
      formData: state.formData,
      setFormData: state.setFormData,
      showEdit: state.showEdit,
      setShowEdit: state.setShowEdit,
      updateData: state.updateData,
    })),
  );
  useEffect(() => {
    if (store.showEdit) {
      if (store.formData) {
        form.setFieldsValue({
          ...store.formData,
          startDate: dayjs(store.formData.startDate),
          endDate: dayjs(store.formData.endDate),
        });
      } else {
        form.setFieldsValue(defaultValues);
      }
    }
    return () => {
      form.setFieldsValue(defaultValues);
    };
  }, [store.formData, store.showEdit]);
  const onSubmit = async (data: any) => {
    // 将dayjs对象转换为时间字符串
    const formattedData = {
      ...data,
      id: store.formData?.id,
      startDate: data.startDate ? data.startDate.format('YYYY-MM-DD') : undefined,
      endDate: data.endDate ? data.endDate.format('YYYY-MM-DD') : undefined,
    };
    const res = await store.updateData(formattedData, { refresh: true });
    if (res.code === 200) {
      store.setShowEdit(false);
      store.setFormData(undefined);
    }
  };
  const onCancel = () => {
    store.setShowEdit(false);
    store.setFormData(undefined);
  };
  const hasId = !!store.formData?.id;
  return (
    <Modal
      title={hasId ? '编辑' : '添加'}
      footer={null}
      open={store.showEdit}
      onCancel={onCancel}
      style={{
        top: 40,
      }}>
      <Form
        form={form}
        labelCol={{
          span: 6,
        }}
        wrapperCol={{
          span: 18,
        }}
        className='flex flex-col gap-4 pt-4 min-w-[400px]'
        onFinish={onSubmit}>
        <Form.Item name='id' hidden>
          <Input />
        </Form.Item>
        <Form.Item name='title' label='标题' rules={[{ required: true, message: '请输入标题' }]}>
          <Input placeholder='请输入标题' />
        </Form.Item>
        <Form.Item name='userId' label='用户ID' rules={[{ required: true, message: '请输入用户ID' }]}>
          <Input placeholder='请输入用户ID' />
        </Form.Item>
        <Form.Item name='level' label='等级' rules={[{ required: true, message: '请选择等级' }]}>
          <Select options={vipLevel} />
        </Form.Item>
        <Form.Item name='category' label='分类' rules={[{ required: true, message: '请选择分类' }]}>
          <Select options={VipCategory} />
        </Form.Item>
        <Form.Item name='startDate' label='开始日期' rules={[{ required: true, message: '请选择开始日期' }]}>
          <DatePicker format={'YYYY-MM-DD'} type='date' />
        </Form.Item>
        <Form.Item name='endDate' label='结束日期' rules={[{ required: true, message: '请选择结束日期' }]}>
          <DatePicker format={'YYYY-MM-DD'} type='date' />
        </Form.Item>
        <Form.Item label=' ' colon={false}>
          <Button htmlType='submit'>提交</Button>
        </Form.Item>
      </Form>
    </Modal>
  );
};

export const List = () => {
  const store = useDemoStore(
    useShallow((state) => ({
      list: state.list,
      pagination: state.pagination,
      init: state.init,
      setShowEdit: state.setShowEdit,
      deleteData: state.deleteData,
      setFormData: state.setFormData,
      getList: state.getList,
    })),
  );
  useEffect(() => {
    store.init();
  }, []);
  const columns: ColumnType<any>[] = [
    {
      title: '标题',
      dataIndex: 'title',
      align: 'center',
    },
    {
      title: '用户ID',
      dataIndex: 'userId',
      align: 'center',
    },
    {
      title: '等级',
      dataIndex: 'level',
      align: 'center',
    },
    {
      title: '分类',
      dataIndex: 'category',
      align: 'center',
    },
    {
      title: '开始日期',
      dataIndex: 'startDate',
      align: 'center',
      render: (_, record) => {
        return record.startDate ? dayjs(record.startDate).format('YYYY-MM-DD') : '';
      },
    },
    {
      title: '结束日期',
      dataIndex: 'endDate',
      align: 'center',
      render: (_, record) => {
        return record.endDate ? dayjs(record.endDate).format('YYYY-MM-DD') : '';
      },
    },
    {
      title: '操作',
      dataIndex: 'action',
      align: 'center',
      render: (_, record) => (
        <Space>
          <Button
            type='link'
            onClick={() => {
              store.setShowEdit(true);
              store.setFormData(record);
            }}>
            编辑
          </Button>
          <Button type='link' onClick={() => store.deleteData(record.id)}>
            删除
          </Button>
        </Space>
      ),
    },
  ];
  const [formSearch] = Form.useForm();
  const onSearch = (data: any) => {
    console.log('onSearch', data);
    store.getList(data);
  };
  return (
    <div className='w-full h-full flex flex-col gap-2 bg-gray-100 p-4'>
      <div
        className='overflow-auto scrollbar relative'
        style={{
          height: 'calc(100% - 50px)',
          overflow: 'auto',
        }}>
        <Form form={formSearch} onFinish={onSearch} layout='inline' className='sticky top-0 left-0 z-10 flex gap-2 flex-wrap'>
          <Button type='primary' onClick={() => store.setShowEdit(true)}>
            添加
          </Button>
          <Form.Item className='w-[200px]' name='search' label='标题'>
            <Input />
          </Form.Item>
          <Form.Item className='w-[200px]' name='level' label='等级'>
            <Select options={vipLevel} />
          </Form.Item>
          <Form.Item className='w-[22s0px]' name='userId' label='用户ID'>
            <Input />
          </Form.Item>
          <Form.Item className='w-[200px]' name='category' label='分类'>
            <Select options={VipCategory} />
          </Form.Item>
          <Form.Item>
            <Button type='primary' htmlType='submit'>
              搜索
            </Button>
          </Form.Item>
        </Form>
        <Table
          className='mt-2'
          columns={columns}
          rowKey={(record) => record.id}
          dataSource={store.list}
          pagination={{
            pageSize: store.pagination.pageSize,
            total: store.pagination.total,
            current: store.pagination.page,
            onChange: (page, pageSize) => {
              store.getList({ page, pageSize });
              console.log('onChange', page, pageSize);
            },
          }}
        />
      </div>
      <EditDialog />
    </div>
  );
};
